<?php

class WC_Shipit_Uniwin_Common_Functions
{

    /**
     * get settings table name
     */
    public static function settings_tbl_name()
    {
        global $wpdb;
        $tblname = $wpdb->prefix . 'shipit_uniwin_settings';
        return $tblname;
    }
    /**
     * Get sender address from settings
     */

    public static function get_sender_address()
    {
        global $wpdb;
        $tblname = self::settings_tbl_name();
        $result = $wpdb->get_results("SELECT stree_address,city,vat,email,phone,contents,country,name,postcode FROM $tblname WHERE api_is_valid = 1 LIMIT 1");
        return $result;
    }

    /**
     * Get api url from settings
     */
    public static function get_api_url()
    {
        global $wpdb;
        $valid = 1;
        $tblname = self::settings_tbl_name();
        $result = $wpdb->get_var($wpdb->prepare("SELECT api_url FROM $tblname WHERE api_is_valid = %s LIMIT 1", $valid));
        return $result;
    }

    /**
     * Get checkout agents enabled from settings
     */
    public static function get_checkout_is_enabled()
    {
        global $wpdb;
        $valid = 1;
        $tblname = self::settings_tbl_name();
        $result = $wpdb->get_var($wpdb->prepare("SELECT show_carrier FROM $tblname WHERE api_is_valid = %s LIMIT 1", $valid));
        return $result;
    }

    /**
     * Check - Add tracking link to the order completed email enabled
     */
    public static function add_track_url_to_email()
    {
        global $wpdb;
        $tblname = self::settings_tbl_name();
        $valid = 1;
        $result = $wpdb->get_var($wpdb->prepare("SELECT add_track_to_email FROM $tblname WHERE api_is_valid = %s LIMIT 1", $valid));
        return $result;
    }

    /**
     * Check - Outside EU shipment enabled.
     */
    public static function outside_eu_enabled()
    {
        global $wpdb;
        $tblname = self::settings_tbl_name();
        $valid = 1;
        $result = $wpdb->get_var($wpdb->prepare("SELECT outside_eu_shipment FROM $tblname WHERE api_is_valid = %s LIMIT 1", $valid));
        return $result;
    }

    /**
     * Check - product name as description enabled
     */
    public static function product_name_desc()
    {
        global $wpdb;
        $tblname = self::settings_tbl_name();
        $valid = 1;
        $result = $wpdb->get_var($wpdb->prepare("SELECT product_name_desc FROM $tblname WHERE api_is_valid = %s LIMIT 1", $valid));
        return $result;
    }


    /**
     * Get api key from settings
     */
    public static function get_api_key()
    {
        global $wpdb;
        $tblname = self::settings_tbl_name();
        $valid = 1;
        $result = $wpdb->get_var($wpdb->prepare("SELECT api_key FROM $tblname WHERE api_is_valid = %s LIMIT 1", $valid));
        return $result;
    }

    /**
     * Get api secret key from settings
     */

    public static function get_api_secret_key()
    {
        global $wpdb;
        $tblname = self::settings_tbl_name();
        $valid = 1;
        $result = $wpdb->get_var($wpdb->prepare("SELECT secret_key FROM $tblname WHERE api_is_valid =%s LIMIT 1", $valid));
        return $result;
    }


    /**
     * Check printing document enabled in from settings
     */

    public static function printing_shiping_label()
    {
        global $wpdb;
        $tblname = self::settings_tbl_name();
        $valid = 1;
        $result = $wpdb->get_var($wpdb->prepare("SELECT print_shiping_label FROM $tblname WHERE api_is_valid = %s LIMIT 1", $valid));
        return $result;
    }

    /**
     * Check update order status to completed is enabled in from settings
     */

    public static function update_order_to_completed()
    {
        global $wpdb;
        $tblname = self::settings_tbl_name();
        $valid = 1;
        $result = $wpdb->get_var($wpdb->prepare("SELECT set_order_completed FROM $tblname WHERE api_is_valid = %s LIMIT 1", $valid));
        return $result;
    }


    /**
     * get carrier agent style
     */

    public static function get_carrier_agent_style()
    {
        global $wpdb;
        $tblname = self::settings_tbl_name();
        $valid = 1;
        $result = $wpdb->get_var($wpdb->prepare("SELECT agent_style FROM $tblname WHERE api_is_valid = %s LIMIT 1", $valid));
        return $result;
    }


    /**
     * show agent on thankyou page
     */

    public static function show_agent_on_tq_page()
    {
        global $wpdb;
        $tblname = self::settings_tbl_name();
        $valid = 1;
        $result = $wpdb->get_var($wpdb->prepare("SELECT agent_thankyou_page FROM $tblname WHERE api_is_valid = %s LIMIT 1", $valid));
        return $result;
    }


    /**
     * Get settings info
     */
    public static function get_settings_info()
    {
        global $wpdb;
        $tblname = self::settings_tbl_name();
        $result = $wpdb->get_results("SELECT auto_sync,address_sync,pk_width,pk_length,pk_height,pk_parcel,fragile,return_label,order_confirm_email FROM $tblname WHERE api_is_valid = 1 LIMIT 1");
        return $result;
    }

    /**
     * Parse number
     */
    public static function shipit_uniwin_return_parse_number($value, $integer = false)
    {
        $value = floatval(str_replace(',', '.', trim($value)));

        if ($integer) {
            $value = intval(round($value));
        }

        return $value;
    }


    /**
     * Price number formate
     */
    public static function shipit_uniwin_price_formate($value)
    {
        return number_format(floatval($value), 2, ',', ' ');
    }


    /**
     * Calculate checksum
     */
    public static function calculate_checksum($data)
    {
        $key = self::get_api_secret_key();
        $checksum = hash("sha512", (json_encode($data) . $key));
        return $checksum;
    }

    /**
     * Curl header
     */

    public static function curl_header($checksum)
    {

        $api_key = self::get_api_key();
        return array(
            "Content-Type: application/json",
            "X-SHIPIT-KEY: " . $api_key,
            "X-SHIPIT-CHECKSUM: " . $checksum
        );
    }


    /**
     * Curl Post, Put, Get method
     */
    public static function curl_all_method($method, $checksum, $type, $postdata = NULL)
    {
        $api_url = self::get_api_url(); // Get api url
        $url = $api_url . $method;
        $header = self::curl_header($checksum);
        $ch = curl_init();
        curl_setopt($ch, CURLOPT_URL, $url);
        curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
        curl_setopt($ch, CURLOPT_HTTPHEADER, $header);
        if ($type == "POST") {
            curl_setopt($ch, CURLOPT_POST, 1);
            curl_setopt($ch, CURLOPT_POSTFIELDS, $postdata);
        } else if ($type == "PUT") {
            curl_setopt($ch, CURLOPT_CUSTOMREQUEST, "PUT");
            curl_setopt($ch, CURLOPT_POSTFIELDS, $postdata);
        } else if ($type == "GET") {
            curl_setopt($ch, CURLOPT_CUSTOMREQUEST, "GET");
        }
        $response = curl_exec($ch);
        curl_close($ch);
        $r = json_decode($response, true);
        return $r;
    }

    /**
     * Product weight calculation
     */

    public static function weight_calculation($oid)
    {
        $order = wc_get_order($oid);
        $items = $order->get_items();
        $item_weight = 0.0;
        foreach ($items as $item) {
            $product = $item->get_product();
            $item_weight = $item_weight + !empty($product->get_weight()) ? $product->get_weight() : 0;
        }

        $weight_unit = get_option('woocommerce_weight_unit');
        if ($weight_unit == "kg") {
            $weight = $item_weight;
        } else if ($weight_unit == "g") {
            $weight = $item_weight / 1000;
        } else if ($weight_unit == "lbs") {
            $weight = $item_weight * 0.45359237;
        } else if ($weight_unit == "oz") {
            $weight = $item_weight * 0.0283495;
        }
        return $weight;
    }

    /**
     * Remove any spaces and dashes from the phone number to avoid validation errors
     */
    public static function check_phone_no($phone)
    {
        $phone = preg_replace('/\s/', '', $phone);
        $phone = str_replace('-', '', $phone);

        return $phone;
    }

    /**
     * Get shipping phone number from order
     */
    public static function shipit_uniwin_get_shipping_phone($order)
    {
        $shipping_phone = get_post_meta($order->get_id(), '_shipping_phone', true);

        if (!empty($shipping_phone)) {
            return $shipping_phone;
        }

        return $order->get_billing_phone();
    }

    /**
     * Get shipping email id from order
     */
    public static function shipit_uniwin_get_shipping_email($order)
    {
        $shipping_email = get_post_meta($order->get_id(), '_shipping_email', true);

        if (!empty($shipping_email)) {
            return $shipping_email;
        }

        return $order->get_billing_email();
    }

    /**
     * Fetch shipping label
     */
    public static function get_printing_label_data($url)
    {
        $url = str_replace('http://', 'https://', $url);

        $args = [
            'sslverify' => false,
        ];
        $args['headers'] = array(
            'Authorization' => 'Basic ' . base64_encode('shipit' . ':' . 'tulossa'),
        );
        $response = wp_remote_get($url, $args);

        if (!is_wp_error($response)) {
            return wp_remote_retrieve_body($response);
        }
        return FALSE;
    }


    /**
     * Save shipping label in the pdf
     */
    public static function save_printing_label_document($pdf, $id)
    {
        $filepath = self::shipping_label_filepath($id);
        file_put_contents($filepath, $pdf);
        return $filepath;
    }

    /**
     * Get shipping label file path as document
     */
    public static function shipping_label_filepath($id)
    {
        $upload_dir = wp_upload_dir();
        $upload_dir_final = $upload_dir['basedir'] . '/shipit-uniwin';
        $dirname = 'shipit-uniwin';
        $permissions = 0755;
        if (is_dir($upload_dir_final)) {
            $filepath = trailingslashit($upload_dir['basedir']) . 'shipit-uniwin/' . $id . '.pdf';
        } else {
            mkdir($upload_dir_final, $permissions);
            $filepath = trailingslashit($upload_dir['basedir']) . 'shipit-uniwin/' . $id . '.pdf';
        }
        return $filepath;
    }


    /**
     * Get shipping label document URL
     */
    public static function document_url($orderid, $id)
    {
        return home_url() . '/wp-content/uploads/shipit-uniwin/' . $id . '.pdf';
    }

    /**
     * Mark order as completed after printing shipping label
     */
    public static function set_order_as_completed($order_id)
    {

        $order = wc_get_order($order_id);

        if ($order && !$order->has_status('refunded')) {
            $order->update_status('completed', __('Order status changed by Shipit after printing the shipping label.', 'shipit-uniwin'), true);
            do_action('woocommerce_order_edit_status', $order->get_id(), 'completed');
        }
    }
}
