(function ($) {
	'use strict';

	/**
	 * All of the code for your admin-facing JavaScript source
	 * should reside in this file.
	 *
	 * Note: It has been assumed you will write jQuery code here, so the
	 * $ function reference has been prepared for usage within the scope
	 * of this function.
	 *
	 * This enables you to define handlers, for when the DOM is ready:
	 *
	 * $(function() {
	 *
	 * });
	 *
	 * When the window is loaded:
	 *
	 * $( window ).load(function() {
	 *
	 * });
	 *
	 * ...and/or other possibilities.
	 *
	 * Ideally, it is not considered best practise to attach more than a
	 * single DOM-ready or window-load handler for a particular page.
	 * Although scripts in the WordPress core, Plugins and Themes may be
	 * practising this, we should strive to set a better example in our own work.
	 */
	$(".shipit_service_price_div").hide();
	$(document).ready(function () {
		$(document).on("click", ".uniwin_close_price_model", function (e) {
			location.reload();
		});

		if ($.cookie("currenttab") != undefined) {
			var currenttab = $.cookie("currenttab");
			$(".tablinks").removeClass("active");
			$(".tablinks." + currenttab).addClass("active");
			$(".tabcontent").removeClass("active");
			$("#" + currenttab).addClass("active");
			$.removeCookie("currenttab")
		}

		$.validator.setDefaults({
			errorClass: 'help-block',
			highlight: function (element) {
				$(element)
					.closest('.form-group')
					.addClass('has-error');

			},
			unhighlight: function (element, errorClass, validClass) {
				$(element)
					.closest('.form-group')
					.removeClass('has-error')
					.addClass('has-success');
			},
		});
		$("#shipit_uniwin_admin_settings").validate({
			errorElement: 'td',
			errorClass: 'help-block',
			focusInvalid: false,
			ignore: [],
			rules: {
				unishipit_api_key: {
					required: true,
				},
				unishipit_api_secret: {
					required: true,
				},
				unishipit_sender_name: {
					required: true,
					minlength: 3,
				},
				unishipit_sender_street: {
					required: true,
					minlength: 4,
				},
				unishipit_sender_city: {
					required: true,
					minlength: 4,
				},
				unishipit_sender_country: {
					required: true,
				},
				unishipit_sender_postcode: {
					required: true,
					digits: true,
				},
				unishipit_sender_vat: {
					required: true,
					digits: true,
				},
				unishipit_sender_email: {
					required: true,
					email: true
				},
				unishipit_sender_phone: {
					required: true,
					digits: true,
				},
				unishipit_sender_contents: {
					required: true,
				}

			},
			messages: {
				unishipit_api_key: {
					required: "Please enter api key."
				},
				unishipit_api_secret: {
					required: "Please enter secret key."
				},
				unishipit_sender_name: {
					required: "Please enter sender name."
				},
				unishipit_sender_name: {
					required: "Please enter sender name.",
					minlength: "Please enter at least 3 characters."
				},
				unishipit_sender_street: {
					required: "Please enter street address.",
					minlength: "Please enter at least 4 characters."
				},
				unishipit_sender_city: {
					required: "Please enter city.",
					minlength: "Please enter at least 4 characters."
				},
				unishipit_sender_country: {
					required: "Please enter country.",
				},
				unishipit_sender_postcode: {
					required: "Please enter postal code.",
					digits: "Numbers only allowed."
				},
				unishipit_sender_vat: {
					required: "Please enter vat id.",
					digits: "Numbers only allowed."
				},
				unishipit_sender_email: {
					required: "Please enter email.",
					email: "Invalid email id."
				},
				unishipit_sender_phone: {
					required: "Please enter phone number.",
					digits: "Numbers only allowed."
				},
				unishipit_sender_contents: {
					required: "Please enter contents."
				}
			},
			invalidHandler: function (event, validator) { //display error alert on form submit   
				$('.alert-danger', $('.login-form')).show();
				$(".help-block").show();
			},

			highlight: function (e) {
				$(e).closest('.form-group').removeClass('has-info').addClass('error');
				$(".help-block").show();
			},
			unhighlight: function (element) { // <-- fires when element is valid
				$(element).closest('.form-group').removeClass('error').addClass('has-info');
				$(element).closest('.form-group').find('.help-block').remove();
			},


			success: function (e) {
				$(e).closest('.form-group').removeClass('error').addClass('info');
				$(e).remove();
			},

			errorPlacement: function (error, element) {
				error.insertAfter(element.parent());
			},

			submitHandler: function (form) {
				form.submit();
				$('button[type=submit], input[type=submit]').attr('disabled', true);
			},
			invalidHandler: function (form, validator) {
				var errors = validator.numberOfInvalids();
				if (errors) {
					validator.errorList[0].element.focus();
				}
			},
		});

		$(".carrier_agents_assistant").hide();
		$("#unishipit_show_carrier").click(function () {
			if ($(this).is(":checked")) {
				$(".carrier_agents_assistant").show();
			} else {
				$(".carrier_agents_assistant").hide();
			}
		});
		if ($('#unishipit_show_carrier').is(':checked')) {
			$(".carrier_agents_assistant").show();
		}


		$(".unishipit-home-delivery").hide();
		$("#customRadioInline7").click(function () {
			if ($(this).is(":checked")) {
				$(".unishipit-home-delivery").show();
			} else {
				$(".unishipit-home-delivery").hide();
			}
		});
		if ($('#customRadioInline7').is(':checked')) {
			$(".unishipit-home-delivery").show();
		}
		$("#shipit_uniwin_general_settings").validate({
			errorElement: 'td',
			errorClass: 'help-block',
			focusInvalid: false,
			ignore: [],
			rules: {
				unishipit_width: {
					required: true,
					digits: true,
				},
				unishipit_length: {
					required: true,
					digits: true,
				},
				unishipit_height: {
					required: true,
					digits: true,
				},
				unishipit_parcel: {
					required: true,
					digits: true,
				},
				unishipit_hd_width: {
					required: function () {
						if ($("#customRadioInline7").is(':checked')) {
							return true;
						}
						else {
							return false;
						}
					},
					digits: function () {
						if ($("#customRadioInline7").is(':checked')) {
							return true;
						}
						else {
							return false;
						}
					},
				},
				unishipit_hd_length: {
					required: function () {
						if ($("#customRadioInline7").is(':checked')) {
							return true;
						}
						else {
							return false;
						}
					},
					digits: function () {
						if ($("#customRadioInline7").is(':checked')) {
							return true;
						}
						else {
							return false;
						}
					},
				},
				unishipit_hd_height: {
					required: function () {
						if ($("#customRadioInline7").is(':checked')) {
							return true;
						}
						else {
							return false;
						}
					},
					digits: function () {
						if ($("#customRadioInline7").is(':checked')) {
							return true;
						}
						else {
							return false;
						}
					},
				}
			},
			messages: {
				unishipit_width: {
					required: "Please enter width.",
					digits: "Numbers only allowed."
				},
				unishipit_length: {
					required: "Please enter length.",
					digits: "Numbers only allowed."
				},
				unishipit_height: {
					required: "Please enter height.",
					digits: "Numbers only allowed."
				},
				unishipit_parcel: {
					required: "Please enter parcel.",
					digits: "Numbers only allowed."
				},
				unishipit_hd_width: {
					required: "Please enter width for home delivery.",
					digits: "Numbers only allowed."
				},
				unishipit_hd_length: {
					required: "Please enter length for home delivery.",
					digits: "Numbers only allowed."
				},
				unishipit_hd_height: {
					required: "Please enter heigth for home delivery.",
					digits: "Numbers only allowed."
				}
			},
			invalidHandler: function (event, validator) { //display error alert on form submit   
				$('.alert-danger', $('.login-form')).show();
				$(".help-block").show();
			},

			highlight: function (e) {
				$(e).closest('.form-group').removeClass('has-info').addClass('error');
				$(".help-block").show();
			},
			unhighlight: function (element) { // <-- fires when element is valid
				$(element).closest('.form-group').removeClass('error').addClass('has-info');
				$(element).closest('.form-group').find('.help-block').remove();
			},


			success: function (e) {
				$(e).closest('.form-group').removeClass('error').addClass('info');
				$(e).remove();
			},

			errorPlacement: function (error, element) {
				error.insertAfter(element.parent());
			},

			submitHandler: function (form) {
				form.submit();

				$('button[type=submit], input[type=submit]').attr('disabled', true);
				var tabid = $('button[name="gs_save"]').attr("data-tabid");
				$.cookie("currenttab", tabid);
			},
			invalidHandler: function (form, validator) {
				var errors = validator.numberOfInvalids();
				if (errors) {
					validator.errorList[0].element.focus();
				}
			},
		});

		$('#uniwin_shipit_service_field').change(function () {
			var price = $(this).find(':selected').attr('data-price');
			if (price != "") {
				$(".shipit_service_price_div").show();
				$(".shipit_service_price").text(price);
				$('input[name="shipit_uniwin_service_price"]').val(price);
			}

		});


	});



})(jQuery);


function openTab(evt, TabName) {
	var i, tabcontent, tablinks;
	tabcontent = document.getElementsByClassName("tabcontent");
	for (i = 0; i < tabcontent.length; i++) {
		tabcontent[i].style.display = "none";
	}
	tablinks = document.getElementsByClassName("tablinks");
	for (i = 0; i < tablinks.length; i++) {
		tablinks[i].className = tablinks[i].className.replace(" active", "");
	}
	document.getElementById(TabName).style.display = "block";
	evt.currentTarget.className += " active";
}
