<?php
class WC_Shipit_Uniwin_Shipment_Functions
{

    /**
     * Create shipment api using curl method
     */
    public static function create_shipment($POST)
    {
        $method =  'shipment';
        $sender = WC_Shipit_Uniwin_Common_Functions::get_sender_address();
        $check_outside_eu = WC_Shipit_Uniwin_Common_Functions::outside_eu_enabled();
        $order = wc_get_order($POST['oid']);
        // Set shipping names
        $receiver_name = $order->get_shipping_first_name() . ' ' . $order->get_shipping_last_name();
        $contact_name = '';
        if ($order->get_shipping_company()) {
            $receiver_name = $order->get_shipping_company();
            $contact_name = $order->get_shipping_first_name() . ' ' . $order->get_shipping_last_name();
        }
        $error = "";
        $data = [
            "sender" => [
                "name" => $sender[0]->name,
                "email" => $sender[0]->email,
                "phone" => "+" . $sender[0]->phone,
                "address" => $sender[0]->stree_address,
                "city" => $sender[0]->city,
                "postcode" => $sender[0]->postcode,
                "country" => $sender[0]->country,
                "isCompany" => true,
                "contactPerson" => $sender[0]->name,
                "vatNumber" => $sender[0]->vat
            ],
            "receiver" => [
                "name" => $receiver_name,
                "email" => WC_Shipit_Uniwin_Common_Functions::shipit_uniwin_get_shipping_email($order),
                "phone" => WC_Shipit_Uniwin_Common_Functions::check_phone_no(WC_Shipit_Uniwin_Common_Functions::shipit_uniwin_get_shipping_phone($order)),
                "address" => implode(' ', [$order->get_shipping_address_1(), $order->get_shipping_address_2()]),
                "city" => $order->get_shipping_city(),
                "postcode" => $order->get_shipping_postcode(),
                "country" => $POST['uniwin_shipit_country'],
                'isCompany' => !!$order->get_shipping_company(),
                'contactPerson' => $contact_name,
            ],
            "parcels" => [
                [
                    'copies' => $POST['uniwin_shipit_parcel'],
                    "weight" => $POST['uniwin_shipit_weight'],
                    "width" => $POST['uniwin_shipit_width'],
                    "height" => $POST['uniwin_shipit_height'],
                    "length" => $POST['uniwin_shipit_length'],
                    "type" => "PACKAGE",
                    "contents" => $sender[0]->contents
                ]
            ],
            "serviceId" => $POST['uniwin_shipit_service'],
            "type" => "MERCHANDISE",
            "contents" => $sender[0]->contents,
            "returnFreightDoc" => isset($POST['uniwin_shipit_label']) ? true : false,
            "fragile" => isset($POST['uniwin_shipit_fragile']) ? true : false,
            "sendOrderConfirmationEmail" => isset($POST['uniwin_shipit_order_confirm']) ? true : false,
            "freeText" => sprintf('#%s', $order->get_order_number()),
            "reference" => sprintf('#%s', $order->get_order_number()),
            "resellerId" => 8,
            "pickupId" => !empty($POST['uniwin_shipit_pickup']) ? $POST['uniwin_shipit_pickup'] : 0
        ];
        if ($check_outside_eu == 1) {

            $data['proforma'] = [
                "invoiceNumber" => $POST['oid'],
                "invoiceCurrency" => $order->get_currency(),
                "invoiceSubTotal" => (float) $order->get_total() - ($order->get_shipping_total() + $order->get_shipping_tax()),
                "freightCharges" => (float) $order->get_total_shipping() + $order->get_shipping_tax(),
                "invoiceTotal" => (float) $order->get_total()
            ];
            $data['valueAmount'] = (float) $order->get_total();
            // Add items
            $data['items'] = [];
            foreach ($order->get_items() as $item) {

                $customs = self::get_custom_data($order, $item);


                $total = $item->get_total('edit') + $item->get_total_tax('edit');
                $unit_price = round(($total / $item->get_quantity()), 2);

                if ($customs !== false) {
                    $data['items'][] = [
                        'description' => $customs['description'],
                        'quantity' => $item->get_quantity(),
                        'unitValue' => $unit_price,
                        'currency' => $order->get_currency(),
                        'unitWeight' => $customs['unit_weight'],
                        'hsTariffCode' => $customs['tariff_code'],
                        'countryOfOrigin' => $customs['origin'],
                    ];
                }
            }
        }

        $checksum = WC_Shipit_Uniwin_Common_Functions::calculate_checksum($data);
        $postdata = json_encode($data);
        $r = WC_Shipit_Uniwin_Common_Functions::curl_all_method($method, $checksum, "PUT", $postdata);
        return $r;
    }

    /**
     * Get customs information for product in a order
     */
    public static function get_custom_data($order, $item)
    {
        $product = false;
        if (is_callable(array($item, 'get_product'))) {
            $product = $item->get_product();
        }

        if ($product) {
            $product_id = $product->get_id();

            // If product is variation, info must be get from the parent product
            if ('variation' === $product->get_type()) {
                $product_id = $product->get_parent_id();
            }

            $desc = get_post_meta($product_id, '_wc_shipit_uniwin_custom_description', true);
            if (WC_Shipit_Uniwin_Common_Functions::product_name_desc() == 1) {
                $desc = $product->get_name();
            }
            return array(
                'tariff_code' => get_post_meta($product_id, '_wc_shipit_uniwin_tariff_code', true),
                'description' => $desc,
                'origin' => get_post_meta($product_id, '_wc_shipit_uniwin_custom_orgin', true),
                'unit_weight' => floatval($product->get_weight())
            );
        }

        return false;
    }

    /**
     * shipit service price
     */


    public static function shipment_service_price($POST)
    {
        $_POST = $POST;
        $order_id = $_POST['order_id'];
        $weight = WC_Shipit_Uniwin_Common_Functions::shipit_uniwin_return_parse_number($_POST['weight']);
        $height = WC_Shipit_Uniwin_Common_Functions::shipit_uniwin_return_parse_number($_POST['height']);
        $width = WC_Shipit_Uniwin_Common_Functions::shipit_uniwin_return_parse_number($_POST['width']);
        $length = WC_Shipit_Uniwin_Common_Functions::shipit_uniwin_return_parse_number($_POST['length']);
        $parcels = WC_Shipit_Uniwin_Common_Functions::shipit_uniwin_return_parse_number($_POST['parcels'], true);
        $fragile = isset($_POST['fragile']) && $_POST['fragile'] === 'true';

        $order = wc_get_order($order_id);
        if (!$order) {
            die('Order not found with ID ' . $order_id);
        }

        $postcode = $order->get_shipping_postcode();
        $country = $order->get_shipping_country();
        $company_receiver = !!$order->get_shipping_company();

        $sender = WC_Shipit_Uniwin_Common_Functions::get_sender_address();

        $methods = "";

        if (!empty($sender)) {
            $body = [
                'sender' => [
                    "postcode" => $sender[0]->postcode,
                    "country" => $sender[0]->country,
                ],
                'receiver' => [
                    'postcode' => $postcode,
                    'country' => $country,
                ],
                'parcels' => [
                    [
                        'type' => 'PACKAGE',
                        'length' => $length,
                        'width' => $width,
                        'height' => $height,
                        'weight' => $weight,
                        'copies' => $parcels,
                    ]
                ],
                'companyIsReceiving' => $company_receiver,
                'fragile' => $fragile,
                'retrievePickupLocations' => false,
            ];
            $api_url = 'shipping-methods';
            $checksum = WC_Shipit_Uniwin_Common_Functions::calculate_checksum($body);
            $postdata = json_encode($body);
            $response = WC_Shipit_Uniwin_Common_Functions::curl_all_method($api_url, $checksum, "POST", $postdata);
            if ($response['status'] == 1) {
                $methods = $response['methods'];
            }
        }

        return array("postcode" => $postcode, "country" => $country, "width" => $width, "height" => $height, "length" => $length, "weight" => $weight, "fragile" => $fragile, "parcels" => $parcels, "methods" => $methods);
    }

    /**
     * List the available services based on sender and receiver address
     */

    public static function receiver_shipment_service_list($POST)
    {
        $_POST = $POST;
        $sender = WC_Shipit_Uniwin_Common_Functions::get_sender_address();

        if (!empty($sender)) {
            $order = new WC_Order($_POST['post_id']);
            $shipping_address = $order->get_address('shipping');
            $weight = $_POST['weight'];
            $length = ($_POST['length']) ? $_POST['length'] : 15;
            $height = ($_POST['height']) ? $_POST['height'] : 1;
            $width = ($_POST['width']) ? $_POST['width'] : 10;
            $url =  'shipping-methods';
            $data = [
                "sender" => [
                    "postcode" => $sender[0]->postcode,
                    "country" => $sender[0]->country
                ],
                "receiver" => [
                    "postcode" => $shipping_address['postcode'],
                    "country" => $shipping_address['country']
                ],
                "parcels" => [
                    [
                        "type" => "PACKAGE",
                        "length" => $length,
                        "width" => $width,
                        "height" => $height,
                        "weight" => ($weight > 0.0) ? $weight : 0.6,
                    ]
                ],
                "retrievePickupLocations" => false,
                "maxPickupLocations" => 6
            ];
            $checksum = WC_Shipit_Uniwin_Common_Functions::calculate_checksum($data);
            $postdata = json_encode($data);
            $r = WC_Shipit_Uniwin_Common_Functions::curl_all_method($url, $checksum, "POST", $postdata);
            $html = "";
            if ($r['status'] == 1) {
                $html .= '<option value="" data-price="" selected> Select service </option>';
                foreach ($r['methods'] as $methods) {
                    $html .= '<option value="' . $methods['serviceId'] . '" data-price="' . $methods['price'] . '">' . $methods['carrier'] . " - " . $methods['serviceName'] . '</option>';
                }
            } else {
                $html = "<option value=''> No service available</option>";
            }
            $response = array("result" => "success", "html" => $html);
        } else {
            $response = array("result" => "error", "html" => "Please update the shipit settings!");
        }

        return $response;
    }

    /**
     * Get shipit service name by service id
     */

    public static function all_shipit_services($id = NULL)
    {
        $method = "list-methods";
        $checksum = WC_Shipit_Uniwin_Common_Functions::calculate_checksum(array());
        $result = WC_Shipit_Uniwin_Common_Functions::curl_all_method($method, $checksum, "GET", NULL);
        if ($id) {
            $keys = array_search($id, array_column($result, 'serviceId'));
            $carrier_name = $result[$keys]['carrier'] . ' - ' . $result[$keys]['name'];
            return $carrier_name;
        } else {
            return $result;
        }
    }

    /**
     * shipit service in select option - shown in admin order detail meta box
     */
    public static function shipit_uniwin_shipment_service_select_datas($field_name = 'wc_shipit_service_id', $default_value = '', $include_blank = FALSE)
    {
        $html = "";
        $html .= '<select class="wc-enhanced-select form-control" name="' . $field_name . '">';
        if ($include_blank) {
            $html .= '<option value="">No Shipit method</option>';
        }
        foreach (self::all_carriers_agents() as $carrier_id => $carrier) {

            if (empty($carrier['services'])) {
                continue;
            }
            $html .= '<optgroup label="' . $carrier['title'] . '">';
            foreach ($carrier['services'] as $service_id => $carrier_title) {
                $selected = "";
                if ($service_id == $default_value) {
                    $selected = "selected";
                }
                $html .= '<option value="' . $service_id . '" ' . $selected . '>' . $carrier_title . '</option>';
            }
            $html .= ' </optgroup>';
        }
        $html .= '</select>';
        return $html;
    }

    /**
     * Shipment services
     */
    public static function services()
    {
        $services = array();

        foreach (self::all_carriers_agents() as $carrier_id => $carrier) {
            $services = array_merge($services, $carrier['services']);
        }

        return $services;
    }

    /**
     * Shipment all carriers agents
     */
    public static function all_carriers_agents()
    {
        return array(
            'mh' => array(
                'title' => 'Matkahuolto',
                'services' => array(
                    'mh.mh80' => 'Lähellä-paketti',
                    'mh.mh10' => 'Bussipaketti',
                    'mh.mh20' => 'Pikapaketti',
                    'mh.mh3050' => 'Jakopaketti',
                    'mh.mh34' => 'Kotijakelu',
                    'mh.mh84' => 'XXS-paketti',
                    'mh.mh97' => 'Euroopan Kotijakelu',
                    'mh.mh96' => 'Euroopan Jakopaketti',
                    'mh.mh95' => 'Euroopan Lähellä-paketti',
                    'mh.mh34_bike' => 'Pyöräpaketti Kotijakelu',
                    'mh.mh3050_bike' => 'Pyöräpaketti Jakopaketti',
                ),
            ),
            'glsfi' => array(
                'title' => 'GLS',
                'services' => array(
                    'glsfi.glsfiebp' => 'EuroBusinessParcel',
                ),
            ),
            'itellalog' => array(
                'title' => 'Posti',
                'services' => array(),
            ),
            'posti' => array(
                'title' => 'Posti',
                'services' => array(
                    'posti.po2103' => 'Postipaketti',
                    'posti.po2104' => 'Kotipaketti',
                    'posti.po2461' => 'Pikkupaketti',
                    'posti.po2711' => 'Parcel Connect',
                    'posti.po2351' => 'PickUp Parcel',
                    'posti.po2331' => 'Baltian Postipaketti',
                    'posti.po2102' => 'Express',
                    'posti.itpr' => 'Priority',
                    'posti.po2017' => 'EMS',
                    'posti.it14i' => 'Express (international)',
                    'itellalog.pof1' => 'Freight',
                ),
            ),
            'kl' => array(
                'title' => 'DB Schenker',
                'services' => array(),
            ),
            'sbtlfiexp' => array(
                'title' => 'DB Schenker',
                'services' => array(),
            ),
            'sbtlfirrex' => array(
                'title' => 'DB Schenker',
                'services' => array(
                    'sbtlfirrex.sbtlfirrex' => 'Noutopistepaketti',
                    'kl.klgrp' => 'DB SCHENKERsystem',
                    'sbtlfiexp.sbtlfiexp' => 'DB SCHENKERparcel',
                ),
            ),
            'netlux' => array(
                'title' => 'Netlux',
                'services' => array(
                    'netlux.netluxparcel' => 'Parcel',
                    'netlux.netluxpallet' => 'Pallet',
                ),
            ),
            'fiuge' => array(
                'title' => 'Fiuge',
                'services' => array(
                    'fiuge.exprs' => 'Express',
                ),
            ),
            'wolt' => [
                'title' => 'Wolt',
                'services' => [
                    'wolt.wolt' => 'Wolt',
                ],
            ],
            'jakeluyhtio_suomi' => [
                'title' => 'Jakeluyhtiö Suomi',
                'services' => [
                    'jakeluyhtio_suomi.pienpaketti' => 'Pienpaketti',
                ],
            ],
            /*
			'shipit' => array(
				'title' => 'Shipit',
				'services' => array(
					'shipit.shipitexpsv' => 'Shipit Express Saver',
					'shipit.shipitstd' => 'Shipit Standard',
				),
			),
			*/
            'ups' => array(
                'title' => 'UPS',
                'services' => array(
                    'ups.upsexpdtp' => 'Expedited',
                    'ups.upsexpp' => 'Express',
                    'ups.upssavp' => 'Express Saver',
                    'ups.upsstdp' => 'Standard',
                    'ups.accesp' => 'Express Access Point',
                    'ups.accespstd' => 'Access Point Standard',
                ),
            ),
            'plscm' => array(
                'title' => 'Postnord',
                'services' => array(
                    'plscm.p19fi' => 'MyPack',
                    'plscm.p19fidpd' => 'MyPack DPD',
                    'plscm.p17fi' => 'MyPack Home',
                    'plscm.p17fidpd' => 'MyPack Home DPD',
                    'plscm.p18fi' => 'Parcel',
                    'plscm.p18fidpd' => 'Parcel DPD',
                ),
            ),
            'fedex' => array(
                'title' => 'Fedex',
                'services' => array(
                    'fedex.fdxiep' => 'Economy',
                    'fedex.fdxipp' => 'Express',
                ),
            ),
            'itella_ee' => [
                'title' => 'Itella (EE)',
                'services' => [
                    'posti.po2351ee' => 'PickUp Parcel',
                    'posti.po2352ee' => 'Home Parcel',
                    'posti.po2711ee' => 'Parcel Connect Home Delivery',
                    'posti.po2711eepp' => 'Parcel Connect Pickup Points',
                    'posti.it14iee' => 'Business Day Parcel Baltics',
                    'posti.itky14iee' => 'Business Day Pallet Baltics',
                ]
            ],
            'itella_lt' => [
                'title' => 'Itella (LT)',
                'services' => [
                    'posti.po2711lt' => 'Parcel Connect Home Delivery',
                    'posti.po2711ltpp' => 'Parcel Connect Pickup Points',
                ]
            ],
            'itella_lv' => [
                'title' => 'Itella (LV)',
                'services' => [
                    'posti.po2711lv' => 'Parcel Connect Home Delivery',
                    'posti.po2711lvpp' => 'Parcel Connect Pickup Points',
                ]
            ],
            'omni' => [
                'title' => 'Omniva (EE)',
                'services' => [
                    'omni.omnice' => 'Pickup Point Delivery',
                    'omni.omniparcelmachine' => 'Parcelmachine',
                    'omni.omniqk' => 'Courier Delivery',
                    'omni.omnixn' => 'International Maxi Letter',
                ]
            ],
            'dpd' => [
                'title' => 'DPD Baltic (EE)',
                'services' => [
                    'dpd.dindpdbaltpickup' => 'Parcelmachine and Pickup Point',
                    'dpd.dpdeeclassic' => 'Classic',
                    'dpd.dpdbaltpriv' => 'Private',
                    'dpd.dpdeeclassicpallet' => 'Classic Pallet',
                    'dpd.dpdbaltprivpallet' => 'Private Pallet',
                ]
            ],
        );
    }


    /**
     * Title for shipment service
     */
    public static function shipment_service_title($service_code, $with_carrier_title = FALSE)
    {
        $services = self::services();
        if (isset($services[$service_code])) {
            if (!$with_carrier_title) {
                return $services[$service_code];
            } else {
                return sprintf("%s - %s", self::shipment_serivice_carrier_title($service_code), $services[$service_code]);
            }
        }

        return FALSE;
    }


    /**
     * Title for carrier
     */
    public static function shipment_serivice_carrier_title($service_code)
    {
        $carriers = self::all_carriers_agents();

        foreach ($carriers as $carrier_id => $carrier) {
            foreach ($carrier['services'] as $service_id => $service) {
                if ($service_code == $service_id) {
                    return $carrier['title'];
                }
            }
        }

        return false;
    }


    /**
     * get shipment data based on order id
     */

    public static function get_shipment_data($oid)
    {
        global $wpdb;
        $tblname = $wpdb->prefix . 'shipit_uniwin_order_details';
        $result = $wpdb->get_results("SELECT * FROM $tblname WHERE order_id = $oid order by id DESC");
        return $result;
    }
}
