<?php

/**
 * Fired during plugin activation
 *
 * @link       https://uniwin.se
 * @since      1.0.0
 *
 * @package    Shipit_Uniwin
 * @subpackage Shipit_Uniwin/includes
 */

/**
 * Fired during plugin activation.
 *
 * This class defines all code necessary to run during the plugin's activation.
 *
 * @since      1.0.0
 * @package    Shipit_Uniwin
 * @subpackage Shipit_Uniwin/includes
 * @author     uniwin <test@gmail.com>
 */
class Shipit_Uniwin_Activator
{

	/**
	 * Short Description. (use period)
	 *
	 * Long Description.
	 *
	 * @since    1.0.0
	 */
	public static function activate()
	{

		global $wpdb;
		$db_table_name_1 = $wpdb->prefix . 'shipit_uniwin_order_details';  // table name
		$db_table_name_2 = $wpdb->prefix . 'shipit_uniwin_settings';  // table name
		$db_table_name_3 = $wpdb->prefix . 'shipit_uniwin_shipping_mapping';  // table name

		$charset_collate = $wpdb->get_charset_collate();

		//Check to see if the table exists already, if not, then create it
		if ($wpdb->get_var("show tables like '$db_table_name_1'") != $db_table_name_1) {
			$sql = "CREATE TABLE `$db_table_name_1` (
					  `id` int(11) NOT NULL auto_increment,
					  `order_id` varchar(15) NOT NULL,
					  `package_data` LONGTEXT NOT NULL,
					  `shipit_response` LONGTEXT NOT NULL,
					  `status` varchar(10) NOT NULL,
					  `carrier_name` varchar(60) NOT NULL,
					  `created_at` datetime NOT NULL ON UPDATE CURRENT_TIMESTAMP,
					  PRIMARY KEY (`id`)
			  ) $charset_collate;";
			require_once(ABSPATH . 'wp-admin/includes/upgrade.php');
			dbDelta($sql);
		}

		//Check to see if the table exists already, if not, then create it
		if ($wpdb->get_var("show tables like '$db_table_name_2'") != $db_table_name_2) {
			$sql2 = "CREATE TABLE `$db_table_name_2` (
					  `id` int(11) NOT NULL auto_increment,
					  `api_key` varchar(100) NULL,
					  `secret_key` varchar(100) NULL,
					  `mode` varchar(10) NOT NULL,
					  `api_url` varchar(40) NOT NULL,
					  `api_is_valid` int(11) DEFAULT 0,
					  `name` varchar(100) NOT NULL,
					  `stree_address` varchar(255) NOT NULL,
					  `city` varchar(255) NOT NULL,
					  `country` varchar(6) NOT NULL,
					  `postcode` varchar(15) NOT NULL,
					  `vat` int(15) NOT NULL,
					  `email` varchar(165) NOT NULL,
					  `phone` varchar(100) NOT NULL,
					  `contents` varchar(100) NOT NULL,
					  `updated_at` datetime NOT NULL ON UPDATE CURRENT_TIMESTAMP,
					  `auto_sync` int(15) DEFAULT 0,
					  `address_sync` varchar(16) DEFAULT 'shipping',
					  `pk_width` float NULL,
					  `pk_length` float NULL,
					  `pk_height` float NULL,
					  `pk_parcel` float NULL,
					  `fragile` int(11) DEFAULT 1,
					  `return_label` int(11) DEFAULT 1,
					  `order_confirm_email` int(11) DEFAULT 1,
					  `home_delivery` int(11) DEFAULT 0,
					  `hd_width` float NULL,
					  `hd_length` float NULL,
					  `hd_height` float NULL,
					  `show_carrier` int(15) DEFAULT 0,
					  `add_track_to_email` int(15) DEFAULT 0,
					  `product_name_desc` int(15) DEFAULT 0,
					  `outside_eu_shipment` int(15) DEFAULT 0,
					  `print_shiping_label` int(15) DEFAULT 0,
					  `set_order_completed` int(15) DEFAULT 0,
					  `agent_style` varchar(16) DEFAULT 'select',
					  `agent_thankyou_page` int(15) DEFAULT 0,
					  PRIMARY KEY (`id`)
			  ) $charset_collate;";
			require_once(ABSPATH . 'wp-admin/includes/upgrade.php');
			dbDelta($sql2);
		}

		//Check to see if the table exists already, if not, then create it
		if ($wpdb->get_var("show tables like '$db_table_name_3'") != $db_table_name_3) {
			$sql3 = "CREATE TABLE `$db_table_name_3` (
					  `id` int(11) NOT NULL auto_increment,
					  `shipping_method` int(15) NOT NULL,
					  `service_id` varchar(100) NOT NULL,
					  `created_at` datetime NOT NULL ON UPDATE CURRENT_TIMESTAMP,
					  PRIMARY KEY (`id`)
			  ) $charset_collate;";
			require_once(ABSPATH . 'wp-admin/includes/upgrade.php');
			dbDelta($sql3);
		}
	}
}
